@@ -135,17 +135,12 @@ class DatabaseCreation(PostgresDatabaseCreation):
             # This backend raises "ValueError: CockroachDB's EXPLAIN doesn't
             # support any formats." instead of an "unknown format" error.
             'queries.test_explain.ExplainTests.test_unknown_format',
-            # timezones after 2038 use incorrect DST settings:
-            # https://github.com/cockroachdb/django-cockroachdb/issues/124
-            'expressions.tests.FTimeDeltaTests.test_datetime_subtraction_microseconds',
         )
         if self.connection.features.is_cockroachdb_20_1:
             expected_failures += (
-                # InternalError: unexpected error: received 4 results, limit
-                # was 3 (original limit: 3, batch=1 Scan idx=0):
-                # https://github.com/cockroachdb/cockroach/issues/46652
-                'admin_filters.tests.ListFiltersTests.test_simplelistfilter_with_queryset_based_lookups',
-                'expressions_case.tests.CaseExpressionTests.test_update_fk',
+                # timezones after 2038 use incorrect DST settings:
+                # https://github.com/cockroachdb/django-cockroachdb/issues/124
+                'expressions.tests.FTimeDeltaTests.test_datetime_subtraction_microseconds',
             )
         if not self.connection.features.is_cockroachdb_20_1:
             expected_failures += (
@@ -293,6 +288,20 @@ class DatabaseCreation(PostgresDatabaseCreation):
                 klass = getattr(test_module, test_class_name)
                 setattr(test_module, test_class_name, skip('unsupported by cockroachdb')(klass))
 
+        skip_tests = (
+            # CockroachDB has more restrictive blocking than other databases.
+            # https://github.com/cockroachdb/django-cockroachdb/issues/153#issuecomment-664697963
+            'select_for_update.tests.SelectForUpdateTests.test_block',
+        )
+        for test_name in skip_tests:
+            test_case_name, _, method_name = test_name.rpartition('.')
+            test_app = test_name.split('.')[0]
+            # Importing a test app that isn't installed raises RuntimeError.
+            if test_app in settings.INSTALLED_APPS:
+                test_case = import_string(test_case_name)
+                method = getattr(test_case, method_name)
+                setattr(test_case, method_name, skip('unsupported by cockroachdb')(method))
+
     def create_test_db(self, *args, **kwargs):
         # This environment variable is set by teamcity-build/runtests.py or
         # by a developer running the tests locally.
