@@ -7,10 +7,10 @@ from django.utils.functional import cached_property
 
 
 class DatabaseFeatures(PostgresDatabaseFeatures):
-    # Not supported: https://github.com/cockroachdb/cockroach/issues/6583
-    has_select_for_update = False
+    has_select_for_update = property(operator.attrgetter('is_cockroachdb_20_1'))
+    has_select_for_update_of = property(operator.attrgetter('is_cockroachdb_20_1'))
+    # Not supported: https://github.com/cockroachdb/cockroach/issues/40476
     has_select_for_update_nowait = False
-    has_select_for_update_of = False
     has_select_for_update_skip_locked = False
 
     # Not supported: https://github.com/cockroachdb/cockroach/issues/31632
@@ -39,7 +39,6 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
     can_rollback_ddl = False
 
     # Not supported: https://github.com/cockroachdb/cockroach/issues/17511
-    supports_callproc_kwargs = False
     create_test_procedure_without_params_sql = None
     create_test_procedure_with_int_param_sql = None
 
